marktools.Mark
==============

.. abjad-lineage:: abjad.tools.marktools.Mark.Mark.Mark

.. autoclass:: abjad.tools.marktools.Mark.Mark.Mark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Mark.Mark.Mark.start_component
   :noindex:

.. autoattribute:: abjad.tools.marktools.Mark.Mark.Mark.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.attach
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__call__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__delattr__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__eq__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__ge__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__gt__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__le__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__lt__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__ne__
   :noindex:

.. automethod:: abjad.tools.marktools.Mark.Mark.Mark.__repr__
   :noindex:
